# `royalnet` [![PyPI](https://img.shields.io/pypi/v/royalnet.svg)](https://pypi.org/project/royalnet/)

A multipurpose bot framework and webserver

## About

`royalnet` is a Python framework that allows you to create interconnected modular chat bots accessible through multiple interfaces (such as Telegram or Discord), and also modular websites that can be connected with the bots.

### Supported bot platforms

- [Telegram](https://core.telegram.org/bots)
- [Discord](https://discordapp.com/developers/docs/)

## Installing

Installing `royalnet` is a bit messy right now; please wait for the release of `5.1`!

## Documentation

`royalnet`'s documentation is available [here](https://gh.steffo.eu/royalnet).
